LogInfo class
- Implemented types
Constructors
- LogInfo()
Properties
- checkpoint_path ↔ Int8List?
-
getter/setter pair
- commit_log_id ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- log_id ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- term_id ↔ int
-
getter/setter pair
Methods
-
getFieldValue(
int fieldID) → dynamic -
Get a field's value by
fieldId. Primitive types will be wrapped in the appropriate "boxed" types.override -
isSet(
int fieldID) → bool -
Check if a field is currently set or unset, using the
fieldId.override -
isSetCheckpoint_path(
) → bool -
isSetCommit_log_id(
) → bool -
isSetLog_id(
) → bool -
isSetTerm_id(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
TProtocol iprot) → void -
Reads the TObject from the given input protocol.
override
-
setFieldValue(
int fieldID, Object value) → dynamic -
Set a field's value by
fieldId. Primitive types must be "boxed" in the appropriate object wrapper type.override -
toString(
) → String -
A string representation of this object.
override
-
unsetCheckpoint_path(
) → dynamic -
unsetCommit_log_id(
) → dynamic -
unsetLog_id(
) → dynamic -
unsetTerm_id(
) → dynamic -
validate(
) → dynamic -
write(
TProtocol oprot) → void -
Writes the objects out to the
oprotprotocol.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- CHECKPOINT_PATH → const int
- COMMIT_LOG_ID → const int
- LOG_ID → const int
- TERM_ID → const int